@@ -3,15 +3,16 @@
 use lib qw(../blib/lib ../blib/arch ../blib/lib/auto ../blib/arch/auto);
 
 use File::LibMagic ':easy';
-use Benchmark qw(timethese cmpthese);
 
 print MagicBuffer("Hello World\n"),"\n";
 print MagicFile("/bin/ls"),"\n";
 
-my $r=timethese(10_000, {
-	  a => sub { my $a=MagicBuffer("Hi\n"); },
-	  b => sub { my $a=MagicBuffer("Hi\n"); }
-      } );
+print "1: ",MagicBuffer("Test1"),"\n";
+print "2: ",MagicBuffer(""),"\n";
 
-cmpthese($r);
+
+# test if LibMagic can handle undef vars
+my $x;
+print "3: |",MagicBuffer($x),"|\n";
+if (! MagicBuffer($x)) { print "ok\n"; }
 
